@@ -48,6 +48,12 @@ test_that("BipartiteSBM_fit 'Bernoulli' model, undirected, no covariate", {
   mySBM$optimize(verbosity = 0)
   mySBM$setModel(5)
 
+  expect_equal(mySBM$nbConnectParam, nbBlocks[1] * nbBlocks[2])
+  expect_equal(mySBM$penalty, nbBlocks[1] * nbBlocks[2] * log(nbNodes[1] * nbNodes[2]) +  (nbBlocks[1] - 1) * log(nbNodes[1]) + (nbBlocks[2] - 1) * log(nbNodes[2]))
+  expect_equal(mySBM$entropy, -sum(mySBM$probMemberships[[1]] * log(mySBM$probMemberships[[1]]))
+                              -sum(mySBM$probMemberships[[2]] * log(mySBM$probMemberships[[2]])))
+
+
   ## Expectation
   expect_equal(dim(mySBM$expectation), nbNodes)
   expect_true(all(mySBM$expectation >= 0, na.rm = TRUE))
