@@ -7,6 +7,7 @@ nbNodes  <- 40
 nbBlocks <- 2
 blockProp <- c(.5, .5) # group proportions
 covarParam <- c(-2,2)
+dimLabels <- list(row = "rowLabel", col = "colLabel")
 covar1 <- matrix(rnorm(nbNodes**2), nbNodes, nbNodes)
 covar2 <- matrix(rnorm(nbNodes**2), nbNodes, nbNodes)
 covarList_directed <- list(covar1 = covar1, covar2 = covar2)
@@ -22,14 +23,14 @@ test_that("SimpleSBM_fit 'Bernoulli' model, undirected, one covariate", {
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, connectParam, covarParam[1], covarList[1])
+  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, connectParam, covarParam = covarParam[1], covarList = covarList[1])
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList[1])
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernouilli', FALSE, covarList[1]))
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix[1:20, 1:30], 'bernouilli', FALSE, covarList[1]))
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', TRUE, covarList[1]))
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList[[1]]))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList = covarList[1])
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernouilli', FALSE, covarList = covarList[1]))
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix[1:20, 1:30], 'bernouilli', FALSE, covarList = covarList[1]))
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', TRUE, covarList = covarList[1]))
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList = covarList[[1]]))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -41,6 +42,7 @@ test_that("SimpleSBM_fit 'Bernoulli' model, undirected, one covariate", {
   expect_equal(mySBM$modelName, 'bernoulli')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(isSymmetric(mySBM$netMatrix))
@@ -93,13 +95,13 @@ test_that("SimpleSBM_fit 'Bernoulli' model, directed, one covariate", {
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, connectParam, covarParam[1], covarList_directed[1])
+  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, connectParam, dimLabels, covarParam[1], covarList_directed[1])
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', TRUE, covarList_directed[1])
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernouilli', TRUE, covarList_directed[1]))
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList_directed[1]))
-  expect_error(SimpleSBM_fit$new(mySampler$netMatrix[1:20, 1:30], 'bernouilli', FALSE, covarList_directed[1]))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', TRUE, covarList = covarList_directed[1])
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernouilli', TRUE, covarList = covarList_directed[1]))
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix, 'bernoulli', FALSE, covarList = covarList_directed[1]))
+  expect_error(SimpleSBM_fit$new(mySampler$netMatrix[1:20, 1:30], 'bernouilli', FALSE, covarList = covarList_directed[1]))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -111,6 +113,7 @@ test_that("SimpleSBM_fit 'Bernoulli' model, directed, one covariate", {
   expect_equal(mySBM$modelName, 'bernoulli')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1))
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(!isSymmetric(mySBM$netMatrix))
@@ -162,13 +165,13 @@ test_that("SimpleSBM_fit 'Poisson' model, undirected, two covariates", {
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, connectParam, covarParam[1], covarList[1])
+  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, connectParam, covarParam = covarParam[1], covarList = covarList[1])
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'poisson', FALSE, covarList[1])
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poison', FALSE, covarList[1]))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'poisson', FALSE, covarList[1]))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poisson', TRUE, covarList[1]))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'poisson', FALSE, covarList = covarList[1])
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poison', FALSE, covarList = covarList[1]))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'poisson', FALSE, covarList = covarList[1]))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poisson', TRUE, covarList = covarList[1]))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -180,6 +183,7 @@ test_that("SimpleSBM_fit 'Poisson' model, undirected, two covariates", {
   expect_equal(mySBM$modelName, 'poisson')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(isSymmetric(mySBM$netMatrix))
@@ -230,13 +234,13 @@ test_that("SimpleSBM_fit 'Poisson' model, directed, two covariates", {
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, TRUE, blockProp, connectParam, covarParam[1], covarList_directed[1])
+  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, TRUE, blockProp, connectParam, covarParam = covarParam[1], covarList = covarList_directed[1])
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'poisson', TRUE, covarList_directed[1])
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poison', TRUE, covarList_directed[1]))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'poisson', FALSE, covarList_directed[1]))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poisson', FALSE, covarList_directed[1]))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'poisson', TRUE, covarList = covarList_directed[1])
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poison', TRUE, covarList = covarList_directed[1]))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'poisson', FALSE, covarList = covarList_directed[1]))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'poisson', FALSE, covarList = covarList_directed[1]))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -248,6 +252,7 @@ test_that("SimpleSBM_fit 'Poisson' model, directed, two covariates", {
   expect_equal(mySBM$modelName, 'poisson')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1))
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(!isSymmetric(mySBM$netMatrix))
@@ -299,13 +304,13 @@ test_that("SimpleSBM_fit 'Gaussian' model, undirected, two covariates", {
   connectParam <- list(mean = means, var = 2)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, connectParam, covarParam, covarList)
+  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, connectParam, covarParam = covarParam, covarList = covarList)
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'gaussian', FALSE, covarList)
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'normal', FALSE, covarList))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'gaussian', FALSE, covarList))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'gaussian', TRUE, covarList))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'gaussian', FALSE, covarList = covarList)
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'normal', FALSE, covarList = covarList))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'gaussian', FALSE, covarList = covarList))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'gaussian', TRUE, covarList = covarList))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -317,6 +322,7 @@ test_that("SimpleSBM_fit 'Gaussian' model, undirected, two covariates", {
   expect_equal(mySBM$modelName, 'gaussian')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(isSymmetric(mySBM$netMatrix))
@@ -372,13 +378,13 @@ test_that("SimpleSBM_fit 'Gaussian' model, undirected, two covariates", {
   connectParam <- list(mean = means, var = 2)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, blockProp, connectParam, covarParam, covarList_directed)
+  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, blockProp, connectParam, covarParam = covarParam, covarList = covarList_directed)
 
   ## Construction----------------------------------------------------------------
-  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'gaussian', TRUE, covarList_directed)
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'normal', TRUE, covarList_directed))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'gaussian', TRUE, covarList_directed))
-  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'gaussian', FALSE, covarList_directed))
+  mySBM <- SimpleSBM_fit$new(mySampler$netMatrix, 'gaussian', TRUE, covarList = covarList_directed)
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'normal', TRUE, covarList = covarList_directed))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix[1:20, 1:30], 'gaussian', TRUE, covarList = covarList_directed))
+  expect_error(SimpleSBM_fit$new(SamplerBernoulli$netMatrix, 'gaussian', FALSE, covarList = covarList_directed))
 
   ## Checking class
   expect_true(inherits(mySBM, "SBM"))
@@ -390,6 +396,7 @@ test_that("SimpleSBM_fit 'Gaussian' model, undirected, two covariates", {
   expect_equal(mySBM$modelName, 'gaussian')
   expect_equal(mySBM$nbNodes, nbNodes)
   expect_equal(mySBM$dimension, c(nbNodes, nbNodes))
+  expect_equal(mySBM$dimLabels, list(row="rowLabel", col="colLabel"))
   expect_equal(mySBM$nbDyads, nbNodes*(nbNodes - 1))
   expect_true(all(is.na(diag(mySBM$netMatrix))))
   expect_true(!isSymmetric(mySBM$netMatrix))
